@@ -1,4 +1,4 @@
-use crate::{position::Rect, style::Style};
+use crate::{position::Rect, style::Style, Shape, ShapeType};
 
 #[derive(Debug, Clone)]
 pub enum ImageFormat {
@@ -24,3 +24,13 @@ impl Image {
         }
     }
 }
+
+impl Into<Shape> for Image {
+    fn into(self) -> Shape {
+        Shape {
+            pos: self.pos,
+            style: self.style,
+            shape_type: ShapeType::Image { data: self.data },
+        }
+    }
+}
